==> pcb-rnd_1.1.4.orig.tar.bz2: pcb-rnd-1.1.4/src/clip.h <==
/*
 *                            COPYRIGHT
 *
 *  PCB, interactive printed circuit board design
 *  Copyright (C) 1994,1995,1996 Thomas Nau
 *  Copyright (C) 2004 harry eaton
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Contact addresses for paper mail and Email:
 *  Thomas Nau, Schlehenweg 15, 88471 Baustetten, Germany
 *  Thomas.Nau@rz.uni-ulm.de
 *
 */

/* prototypes for inserting points into objects */

#ifndef	PCB_CLIP_H
#define	PCB_CLIP_H

#include "global.h"

/* ---------------------------------------------------------------------------
 * prototypes
 */

/* Clip X,Y to the given bounding box, plus a margin.  Returns TRUE if
   there is something left to be drawn.  */
pcb_bool ClipLine(double minx, double miny, double maxx, double maxy,
							double *x1, double *y1, double *x2, double *y2, double margin);

#endif

==> pcb-rnd_1.2.3.orig.tar.bz2: pcb-rnd-1.2.3/src/clip.h <==
/*
 *                            COPYRIGHT
 *
 *  PCB, interactive printed circuit board design
 *  Copyright (C) 1994,1995,1996 Thomas Nau
 *  Copyright (C) 2004 harry eaton
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Contact addresses for paper mail and Email:
 *  Thomas Nau, Schlehenweg 15, 88471 Baustetten, Germany
 *  Thomas.Nau@rz.uni-ulm.de
 *
 */

/* prototypes for inserting points into objects */

#ifndef	PCB_CLIP_H
#define	PCB_CLIP_H

#include "global_typedefs.h"

/* ---------------------------------------------------------------------------
 * prototypes
 */

/* Clip X,Y to the given bounding box, plus a margin.  Returns pcb_true if
   there is something left to be drawn.  */
pcb_bool pcb_line_clip(double minx, double miny, double maxx, double maxy,
							double *x1, double *y1, double *x2, double *y2, double margin);

#endif
